diff --git a/phpcs.xml.dist b/phpcs.xml.dist
index 4a37fd55de..6854f1ddea 100644
--- a/phpcs.xml.dist
+++ b/phpcs.xml.dist
@@ -26,7 +26,7 @@
 				<element value="authorAndUri"/>
 				<element value="Name"/>
 				<element value="Version"/>
-				<!-- From the result of wp_xmlrpc_server::wp_getPageList() -->
+				<!-- From the result of WP_XMLRPC_Server::wp_getPageList() -->
 				<element value="dateCreated"/>
 
 				<!-- From DOMDocument -->
@@ -182,6 +182,16 @@
 		<exclude-pattern>/src/wp-content/themes/twentyfourteen/taxonomy-post_format\.php</exclude-pattern>
 	</rule>
 
+	<rule ref="WordPress.Files.FileName.InvalidClassFileName">
+		<exclude-pattern>/src/wp-admin/includes/class-wp-list-table-compat\.php</exclude-pattern>
+		<exclude-pattern>/src/wp-includes/class-wp-dependency\.php</exclude-pattern>
+	</rule>
+	<rule ref="PEAR.NamingConventions.ValidClassName.StartWithCapital">
+		<exclude-pattern>/src/wp-admin/includes/class-wp-list-table-compat\.php</exclude-pattern>
+		<exclude-pattern>/src/wp-includes/class-wp-dependency\.php</exclude-pattern>
+		<exclude-pattern>/src/wp-includes/class-wp-editor\.php</exclude-pattern>
+	</rule>
+
 	<!-- Whitelist test classes for select sniffs. -->
 	<rule ref="WordPress.Files.FileName">
 		<properties>
diff --git a/src/wp-admin/includes/ajax-actions.php b/src/wp-admin/includes/ajax-actions.php
index 4b91154c09..12127ca9ad 100644
--- a/src/wp-admin/includes/ajax-actions.php
+++ b/src/wp-admin/includes/ajax-actions.php
@@ -3423,7 +3423,7 @@ function wp_ajax_parse_embed() {
 			wp_send_json_error();
 		}
 		setup_postdata( $post );
-	} elseif ( ! current_user_can( 'edit_posts' ) ) { // See WP_oEmbed_Controller::get_proxy_item_permissions_check().
+	} elseif ( ! current_user_can( 'edit_posts' ) ) { // See WP_OEmbed_Controller::get_proxy_item_permissions_check().
 		wp_send_json_error();
 	}
 
diff --git a/src/wp-admin/includes/class-wp-filesystem-ftpsockets.php b/src/wp-admin/includes/class-wp-filesystem-ftpsockets.php
index 0482663a65..275bab071e 100644
--- a/src/wp-admin/includes/class-wp-filesystem-ftpsockets.php
+++ b/src/wp-admin/includes/class-wp-filesystem-ftpsockets.php
@@ -13,7 +13,7 @@
  *
  * @see WP_Filesystem_Base
  */
-class WP_Filesystem_ftpsockets extends WP_Filesystem_Base {
+class WP_Filesystem_FTPsockets extends WP_Filesystem_Base {
 
 	/**
 	 * @since 2.5.0
diff --git a/src/wp-includes/class-wp-embed.php b/src/wp-includes/class-wp-embed.php
index c8aec5a006..1609716d1d 100644
--- a/src/wp-includes/class-wp-embed.php
+++ b/src/wp-includes/class-wp-embed.php
@@ -130,7 +130,7 @@ class WP_Embed {
 	 *
 	 * Attempts to convert a URL into embed HTML. Starts by checking the URL against the regex of
 	 * the registered embed handlers. If none of the regex matches and it's enabled, then the URL
-	 * will be given to the WP_oEmbed class.
+	 * will be given to the WP_OEmbed class.
 	 *
 	 * @param array $attr {
 	 *     Shortcode attributes. Optional.
@@ -263,7 +263,7 @@ class WP_Embed {
 		 * @since 2.9.0
 		 * @since 4.4.0 The default value changed to true.
 		 *
-		 * @see WP_oEmbed::discover()
+		 * @see WP_OEmbed::discover()
 		 *
 		 * @param bool $enable Whether to enable `<link>` tag discovery. Default true.
 		 */
diff --git a/src/wp-includes/class-wp-text-diff-renderer-inline.php b/src/wp-includes/class-wp-text-diff-renderer-inline.php
index 62a33033e3..ff70501990 100644
--- a/src/wp-includes/class-wp-text-diff-renderer-inline.php
+++ b/src/wp-includes/class-wp-text-diff-renderer-inline.php
@@ -1,6 +1,6 @@
 <?php
 /**
- * Diff API: WP_Text_Diff_Renderer_inline class
+ * Diff API: WP_Text_Diff_Renderer_Inline class
  *
  * @package WordPress
  * @subpackage Diff
@@ -13,7 +13,7 @@
  * @since 2.6.0
  * @uses Text_Diff_Renderer_inline Extends
  */
-class WP_Text_Diff_Renderer_inline extends Text_Diff_Renderer_inline {
+class WP_Text_Diff_Renderer_Inline extends Text_Diff_Renderer_inline {
 
 	/**
 	 * @ignore
diff --git a/src/wp-includes/class-wp-text-diff-renderer-table.php b/src/wp-includes/class-wp-text-diff-renderer-table.php
index e4e06a43b4..17d736ee75 100644
--- a/src/wp-includes/class-wp-text-diff-renderer-table.php
+++ b/src/wp-includes/class-wp-text-diff-renderer-table.php
@@ -43,7 +43,7 @@ class WP_Text_Diff_Renderer_Table extends Text_Diff_Renderer {
 	 * @var string
 	 * @since 2.6.0
 	 */
-	protected $inline_diff_renderer = 'WP_Text_Diff_Renderer_inline';
+	protected $inline_diff_renderer = 'WP_Text_Diff_Renderer_Inline';
 
 	/**
 	 * Should we show the split view or not
diff --git a/src/wp-includes/class-wp-xmlrpc-server.php b/src/wp-includes/class-wp-xmlrpc-server.php
index 72aeef2048..b3a957741c 100644
--- a/src/wp-includes/class-wp-xmlrpc-server.php
+++ b/src/wp-includes/class-wp-xmlrpc-server.php
@@ -14,13 +14,13 @@
  * options, etc.
  *
  * As of WordPress 3.5.0, XML-RPC is enabled by default. It can be disabled
- * via the {@see 'xmlrpc_enabled'} filter found in wp_xmlrpc_server::login().
+ * via the {@see 'xmlrpc_enabled'} filter found in WP_XMLRPC_Server::login().
  *
  * @since 1.5.0
  *
  * @see IXR_Server
  */
-class wp_xmlrpc_server extends IXR_Server {
+class WP_XMLRPC_Server extends IXR_Server {
 	/**
 	 * Methods.
 	 *
@@ -43,7 +43,7 @@ class wp_xmlrpc_server extends IXR_Server {
 	public $error;
 
 	/**
-	 * Flags that the user authentication has failed in this instance of wp_xmlrpc_server.
+	 * Flags that the user authentication has failed in this instance of WP_XMLRPC_Server.
 	 *
 	 * @var bool
 	 */
@@ -278,7 +278,7 @@ class wp_xmlrpc_server extends IXR_Server {
 		if ( is_wp_error( $user ) ) {
 			$this->error = new IXR_Error( 403, __( 'Incorrect username or password.' ) );
 
-			// Flag that authentication has failed once on this wp_xmlrpc_server instance
+			// Flag that authentication has failed once on this WP_XMLRPC_Server instance
 			$this->auth_failed = true;
 
 			/**
@@ -301,8 +301,8 @@ class wp_xmlrpc_server extends IXR_Server {
 	 * Check user's credentials. Deprecated.
 	 *
 	 * @since 1.5.0
-	 * @deprecated 2.8.0 Use wp_xmlrpc_server::login()
-	 * @see wp_xmlrpc_server::login()
+	 * @deprecated 2.8.0 Use WP_XMLRPC_Server::login()
+	 * @see WP_XMLRPC_Server::login()
 	 *
 	 * @param string $username User's username.
 	 * @param string $password User's password.
@@ -2985,7 +2985,7 @@ class wp_xmlrpc_server extends IXR_Server {
 	 *
 	 * @since 2.2.0
 	 *
-	 * @see wp_xmlrpc_server::mw_newPost()
+	 * @see WP_XMLRPC_Server::mw_newPost()
 	 *
 	 * @param array  $args {
 	 *     Method arguments. Note: arguments must be ordered as documented.
@@ -3554,7 +3554,7 @@ class wp_xmlrpc_server extends IXR_Server {
 	 *     @type string $password
 	 *     @type array  $struct
 	 * }
-	 * @return array|IXR_Error Contains a collection of comments. See wp_xmlrpc_server::wp_getComment() for a description of each item contents
+	 * @return array|IXR_Error Contains a collection of comments. See WP_XMLRPC_Server::wp_getComment() for a description of each item contents
 	 */
 	public function wp_getComments( $args ) {
 		$this->escape( $args );
@@ -4307,7 +4307,7 @@ class wp_xmlrpc_server extends IXR_Server {
 	 *     @type string $password
 	 *     @type array  $struct
 	 * }
-	 * @return array|IXR_Error Contains a collection of media items. See wp_xmlrpc_server::wp_getMediaItem() for a description of each item contents
+	 * @return array|IXR_Error Contains a collection of media items. See WP_XMLRPC_Server::wp_getMediaItem() for a description of each item contents
 	 */
 	public function wp_getMediaLibrary( $args ) {
 		$this->escape( $args );
diff --git a/src/wp-includes/deprecated.php b/src/wp-includes/deprecated.php
index 677a9b5d44..6e2f1f77ab 100644
--- a/src/wp-includes/deprecated.php
+++ b/src/wp-includes/deprecated.php
@@ -3410,7 +3410,7 @@ function default_topic_count_text( $count ) {
 /**
  * Formerly used to escape strings before inserting into the DB.
  *
- * Has not performed this function for many, many years. Use wpdb::prepare() instead.
+ * Has not performed this function for many, many years. Use WPDB::prepare() instead.
  *
  * @since 0.71
  * @deprecated 3.9.0
@@ -3427,14 +3427,14 @@ function format_to_post( $content ) {
  * Formerly used to escape strings before searching the DB. It was poorly documented and never worked as described.
  *
  * @since 2.5.0
- * @deprecated 4.0.0 Use wpdb::esc_like()
- * @see wpdb::esc_like()
+ * @deprecated 4.0.0 Use WPDB::esc_like()
+ * @see WPDB::esc_like()
  *
  * @param string $text The text to be escaped.
  * @return string text, safe for inclusion in LIKE query.
  */
 function like_escape($text) {
-	_deprecated_function( __FUNCTION__, '4.0.0', 'wpdb::esc_like()' );
+	_deprecated_function( __FUNCTION__, '4.0.0', 'WPDB::esc_like()' );
 	return str_replace( array( "%", "_" ), array( "\\%", "\\_" ), $text );
 }
 
diff --git a/src/wp-includes/embed.php b/src/wp-includes/embed.php
index 76d937cd6c..222f779176 100644
--- a/src/wp-includes/embed.php
+++ b/src/wp-includes/embed.php
@@ -88,7 +88,7 @@ function wp_embed_defaults( $url = '' ) {
  *
  * @since 2.9.0
  *
- * @see WP_oEmbed
+ * @see WP_OEmbed
  *
  * @param string $url  The URL that should be embedded.
  * @param array  $args Optional. Additional arguments and parameters for retrieving embed HTML.
@@ -101,20 +101,20 @@ function wp_oembed_get( $url, $args = '' ) {
 }
 
 /**
- * Returns the initialized WP_oEmbed object.
+ * Returns the initialized WP_OEmbed object.
  *
  * @since 2.9.0
  * @access private
  *
- * @staticvar WP_oEmbed $wp_oembed
+ * @staticvar WP_OEmbed $wp_oembed
  *
- * @return WP_oEmbed object.
+ * @return WP_OEmbed object.
  */
 function _wp_oembed_get_object() {
 	static $wp_oembed = null;
 
 	if ( is_null( $wp_oembed ) ) {
-		$wp_oembed = new WP_oEmbed();
+		$wp_oembed = new WP_OEmbed();
 	}
 	return $wp_oembed;
 }
@@ -124,7 +124,7 @@ function _wp_oembed_get_object() {
  *
  * @since 2.9.0
  *
- * @see WP_oEmbed
+ * @see WP_OEmbed
  *
  * @param string  $format   The format of URL that this provider can handle. You can use asterisks
  *                          as wildcards.
@@ -136,7 +136,7 @@ function wp_oembed_add_provider( $format, $provider, $regex = false ) {
 		$oembed                       = _wp_oembed_get_object();
 		$oembed->providers[ $format ] = array( $provider, $regex );
 	} else {
-		WP_oEmbed::_add_provider_early( $format, $provider, $regex );
+		WP_OEmbed::_add_provider_early( $format, $provider, $regex );
 	}
 }
 
@@ -145,7 +145,7 @@ function wp_oembed_add_provider( $format, $provider, $regex = false ) {
  *
  * @since 3.5.0
  *
- * @see WP_oEmbed
+ * @see WP_OEmbed
  *
  * @param string $format The URL format for the oEmbed provider to remove.
  * @return bool Was the provider removed successfully?
@@ -159,7 +159,7 @@ function wp_oembed_remove_provider( $format ) {
 			return true;
 		}
 	} else {
-		WP_oEmbed::_remove_provider_early( $format );
+		WP_OEmbed::_remove_provider_early( $format );
 	}
 
 	return false;
@@ -310,7 +310,7 @@ function wp_embed_handler_video( $matches, $attr, $url, $rawattr ) {
  * @since 4.4.0
  */
 function wp_oembed_register_route() {
-	$controller = new WP_oEmbed_Controller();
+	$controller = new WP_OEmbed_Controller();
 	$controller->register_routes();
 }
 
diff --git a/src/wp-includes/formatting.php b/src/wp-includes/formatting.php
index ea7b80d6c2..8145fd9e12 100644
--- a/src/wp-includes/formatting.php
+++ b/src/wp-includes/formatting.php
@@ -4161,7 +4161,7 @@ function _deep_replace( $search, $subject ) {
 /**
  * Escapes data for use in a MySQL query.
  *
- * Usually you should prepare queries using wpdb::prepare().
+ * Usually you should prepare queries using WPDB::prepare().
  * Sometimes, spot-escaping is required or useful. One example
  * is preparing an array for use in an IN clause.
  *
diff --git a/src/wp-includes/functions.php b/src/wp-includes/functions.php
index a66b3fa406..c3b0862a60 100644
--- a/src/wp-includes/functions.php
+++ b/src/wp-includes/functions.php
@@ -3393,14 +3393,14 @@ function _jsonp_wp_die_handler( $message, $title = '', $args = array() ) {
  * @since 3.2.0
  * @access private
  *
- * @global wp_xmlrpc_server $wp_xmlrpc_server
+ * @global WP_XMLRPC_Server $WP_XMLRPC_Server
  *
  * @param string       $message Error message.
  * @param string       $title   Optional. Error title. Default empty.
  * @param string|array $args    Optional. Arguments to control behavior. Default empty array.
  */
 function _xmlrpc_wp_die_handler( $message, $title = '', $args = array() ) {
-	global $wp_xmlrpc_server;
+	global $WP_XMLRPC_Server;
 
 	list( $message, $title, $r ) = _wp_die_process_input( $message, $title, $args );
 
@@ -3408,9 +3408,9 @@ function _xmlrpc_wp_die_handler( $message, $title = '', $args = array() ) {
 		nocache_headers();
 	}
 
-	if ( $wp_xmlrpc_server ) {
+	if ( $WP_XMLRPC_Server ) {
 		$error = new IXR_Error( $r['response'], $message );
-		$wp_xmlrpc_server->output( $error->getXml() );
+		$WP_XMLRPC_Server->output( $error->getXml() );
 	}
 	if ( $r['exit'] ) {
 		die();
diff --git a/src/wp-includes/load.php b/src/wp-includes/load.php
index 7e5314c0d2..aa7b9c0daf 100644
--- a/src/wp-includes/load.php
+++ b/src/wp-includes/load.php
@@ -425,7 +425,7 @@ function require_wp_db() {
 	$dbname     = defined( 'DB_NAME' ) ? DB_NAME : '';
 	$dbhost     = defined( 'DB_HOST' ) ? DB_HOST : '';
 
-	$wpdb = new wpdb( $dbuser, $dbpassword, $dbname, $dbhost );
+	$wpdb = new WPDB( $dbuser, $dbpassword, $dbname, $dbhost );
 }
 
 /**
diff --git a/src/wp-includes/wp-db.php b/src/wp-includes/wp-db.php
index 3c41943e55..2b0eb5ecd7 100644
--- a/src/wp-includes/wp-db.php
+++ b/src/wp-includes/wp-db.php
@@ -48,7 +48,7 @@ define( 'ARRAY_N', 'ARRAY_N' );
  *
  * @since 0.71
  */
-class wpdb {
+class WPDB {
 
 	/**
 	 * Whether to show SQL/DB errors.
@@ -161,7 +161,7 @@ class wpdb {
 	 * Flag to ensure we don't run into recursion problems when checking the collation.
 	 *
 	 * @since 4.2.0
-	 * @see wpdb::check_safe_collation()
+	 * @see WPDB::check_safe_collation()
 	 * @var bool
 	 */
 	private $checking_collation = false;
@@ -200,7 +200,7 @@ class wpdb {
 	 * The number of times to retry reconnecting before dying.
 	 *
 	 * @since 3.9.0
-	 * @see wpdb::check_connection()
+	 * @see WPDB::check_connection()
 	 * @var int
 	 */
 	protected $reconnect_retries = 5;
@@ -253,7 +253,7 @@ class wpdb {
 	 * List of WordPress per-blog tables
 	 *
 	 * @since 2.5.0
-	 * @see wpdb::tables()
+	 * @see WPDB::tables()
 	 * @var array
 	 */
 	var $tables = array(
@@ -275,7 +275,7 @@ class wpdb {
 	 * categories, post2cat, and link2cat were deprecated in 2.3.0, db version 5539
 	 *
 	 * @since 2.9.0
-	 * @see wpdb::tables()
+	 * @see WPDB::tables()
 	 * @var array
 	 */
 	var $old_tables = array( 'categories', 'post2cat', 'link2cat' );
@@ -284,7 +284,7 @@ class wpdb {
 	 * List of WordPress global tables
 	 *
 	 * @since 3.0.0
-	 * @see wpdb::tables()
+	 * @see WPDB::tables()
 	 * @var array
 	 */
 	var $global_tables = array( 'users', 'usermeta' );
@@ -293,7 +293,7 @@ class wpdb {
 	 * List of Multisite global tables
 	 *
 	 * @since 3.0.0
-	 * @see wpdb::tables()
+	 * @see WPDB::tables()
 	 * @var array
 	 */
 	var $ms_global_tables = array(
@@ -477,10 +477,10 @@ class wpdb {
 	 * Keys are column names, values are format types: 'ID' => '%d'
 	 *
 	 * @since 2.8.0
-	 * @see wpdb::prepare()
-	 * @see wpdb::insert()
-	 * @see wpdb::update()
-	 * @see wpdb::delete()
+	 * @see WPDB::prepare()
+	 * @see WPDB::insert()
+	 * @see WPDB::update()
+	 * @see WPDB::delete()
 	 * @see wp_set_wpdb_vars()
 	 * @var array
 	 */
@@ -642,7 +642,7 @@ class wpdb {
 	/**
 	 * PHP5 style destructor and will run when database object is destroyed.
 	 *
-	 * @see wpdb::__construct()
+	 * @see WPDB::__construct()
 	 * @since 2.0.8
 	 * @return true
 	 */
@@ -899,7 +899,7 @@ class wpdb {
 	 * @since 2.5.0
 	 *
 	 * @param string $prefix          Alphanumeric name for the new prefix.
-	 * @param bool   $set_table_names Optional. Whether the table names, e.g. wpdb::$posts, should be updated or not.
+	 * @param bool   $set_table_names Optional. Whether the table names, e.g. WPDB::$posts, should be updated or not.
 	 * @return string|WP_Error Old prefix or WP_Error on error
 	 */
 	public function set_prefix( $prefix, $set_table_names = true ) {
@@ -1007,15 +1007,15 @@ class wpdb {
 	 * 'old' - returns tables which are deprecated.
 	 *
 	 * @since 3.0.0
-	 * @uses wpdb::$tables
-	 * @uses wpdb::$old_tables
-	 * @uses wpdb::$global_tables
-	 * @uses wpdb::$ms_global_tables
+	 * @uses WPDB::$tables
+	 * @uses WPDB::$old_tables
+	 * @uses WPDB::$global_tables
+	 * @uses WPDB::$ms_global_tables
 	 *
 	 * @param string $scope   Optional. Can be all, global, ms_global, blog, or old tables. Defaults to all.
 	 * @param bool   $prefix  Optional. Whether to include table prefixes. Default true. If blog
 	 *                        prefix is requested, then the custom users and usermeta tables will be mapped.
-	 * @param int    $blog_id Optional. The blog_id to prefix. Defaults to wpdb::$blogid. Used only when prefix is requested.
+	 * @param int    $blog_id Optional. The blog_id to prefix. Defaults to WPDB::$blogid. Used only when prefix is requested.
 	 * @return array Table names. When a prefix is requested, the key is the unprefixed table name.
 	 */
 	public function tables( $scope = 'all', $prefix = true, $blog_id = 0 ) {
@@ -1139,11 +1139,11 @@ class wpdb {
 	/**
 	 * Do not use, deprecated.
 	 *
-	 * Use esc_sql() or wpdb::prepare() instead.
+	 * Use esc_sql() or WPDB::prepare() instead.
 	 *
 	 * @since 2.8.0
-	 * @deprecated 3.6.0 Use wpdb::prepare()
-	 * @see wpdb::prepare
+	 * @deprecated 3.6.0 Use WPDB::prepare()
+	 * @see WPDB::prepare
 	 * @see esc_sql()
 	 *
 	 * @param string $string
@@ -1151,7 +1151,7 @@ class wpdb {
 	 */
 	function _weak_escape( $string ) {
 		if ( func_num_args() === 1 && function_exists( '_deprecated_function' ) ) {
-			_deprecated_function( __METHOD__, '3.6.0', 'wpdb::prepare() or esc_sql()' );
+			_deprecated_function( __METHOD__, '3.6.0', 'WPDB::prepare() or esc_sql()' );
 		}
 		return addslashes( $string );
 	}
@@ -1190,7 +1190,7 @@ class wpdb {
 	/**
 	 * Escape data. Works on arrays.
 	 *
-	 * @uses wpdb::_real_escape()
+	 * @uses WPDB::_real_escape()
 	 * @since  2.8.0
 	 *
 	 * @param  string|array $data
@@ -1215,11 +1215,11 @@ class wpdb {
 	/**
 	 * Do not use, deprecated.
 	 *
-	 * Use esc_sql() or wpdb::prepare() instead.
+	 * Use esc_sql() or WPDB::prepare() instead.
 	 *
 	 * @since 0.71
-	 * @deprecated 3.6.0 Use wpdb::prepare()
-	 * @see wpdb::prepare()
+	 * @deprecated 3.6.0 Use WPDB::prepare()
+	 * @see WPDB::prepare()
 	 * @see esc_sql()
 	 *
 	 * @param mixed $data
@@ -1227,7 +1227,7 @@ class wpdb {
 	 */
 	public function escape( $data ) {
 		if ( func_num_args() === 1 && function_exists( '_deprecated_function' ) ) {
-			_deprecated_function( __METHOD__, '3.6.0', 'wpdb::prepare() or esc_sql()' );
+			_deprecated_function( __METHOD__, '3.6.0', 'WPDB::prepare() or esc_sql()' );
 		}
 		if ( is_array( $data ) ) {
 			foreach ( $data as $k => $v ) {
@@ -1247,7 +1247,7 @@ class wpdb {
 	/**
 	 * Escapes content by reference for insertion into the database, for security
 	 *
-	 * @uses wpdb::_real_escape()
+	 * @uses WPDB::_real_escape()
 	 *
 	 * @since 2.3.0
 	 *
@@ -1274,7 +1274,7 @@ class wpdb {
 	 *
 	 * Literal percentage signs (%) in the query string must be written as %%. Percentage wildcards (for example,
 	 * to use in LIKE syntax) must be passed via a substitution argument containing the complete LIKE string, these
-	 * cannot be inserted directly in the query string. Also see wpdb::esc_like().
+	 * cannot be inserted directly in the query string. Also see WPDB::esc_like().
 	 *
 	 * Arguments may be passed as individual arguments to the method, or as a single array containing all arguments. A combination
 	 * of the two is not supported.
@@ -1300,7 +1300,7 @@ class wpdb {
 		// This is not meant to be foolproof -- but it will catch obviously incorrect usage.
 		if ( strpos( $query, '%' ) === false ) {
 			wp_load_translations_early();
-			_doing_it_wrong( 'wpdb::prepare', sprintf( __( 'The query argument of %s must have a placeholder.' ), 'wpdb::prepare()' ), '3.9.0' );
+			_doing_it_wrong( 'WPDB::prepare', sprintf( __( 'The query argument of %s must have a placeholder.' ), 'WPDB::prepare()' ), '3.9.0' );
 		}
 
 		$args = func_get_args();
@@ -1316,7 +1316,7 @@ class wpdb {
 		foreach ( $args as $arg ) {
 			if ( ! is_scalar( $arg ) && ! is_null( $arg ) ) {
 				wp_load_translations_early();
-				_doing_it_wrong( 'wpdb::prepare', sprintf( __( 'Unsupported value type (%s).' ), gettype( $arg ) ), '4.8.2' );
+				_doing_it_wrong( 'WPDB::prepare', sprintf( __( 'Unsupported value type (%s).' ), gettype( $arg ) ), '4.8.2' );
 			}
 		}
 
@@ -1353,7 +1353,7 @@ class wpdb {
 			if ( 1 === $placeholders && $passed_as_array ) {
 				// If the passed query only expected one argument, but the wrong number of arguments were sent as an array, bail.
 				wp_load_translations_early();
-				_doing_it_wrong( 'wpdb::prepare', __( 'The query only expected one placeholder, but an array of multiple placeholders was sent.' ), '4.9.0' );
+				_doing_it_wrong( 'WPDB::prepare', __( 'The query only expected one placeholder, but an array of multiple placeholders was sent.' ), '4.9.0' );
 
 				return;
 			} else {
@@ -1363,7 +1363,7 @@ class wpdb {
 				 */
 				wp_load_translations_early();
 				_doing_it_wrong(
-					'wpdb::prepare',
+					'WPDB::prepare',
 					/* translators: 1: number of placeholders, 2: number of arguments passed */
 					sprintf(
 						__( 'The query does not contain the correct number of placeholders (%1$d) for the number of arguments passed (%2$d).' ),
@@ -1384,7 +1384,7 @@ class wpdb {
 	/**
 	 * First half of escaping for LIKE special characters % and _ before preparing for MySQL.
 	 *
-	 * Use this only before wpdb::prepare() or esc_sql().  Reversing the order is very bad for security.
+	 * Use this only before WPDB::prepare() or esc_sql().  Reversing the order is very bad for security.
 	 *
 	 * Example Prepared Statement:
 	 *
@@ -1401,7 +1401,7 @@ class wpdb {
 	 *
 	 * @param string $text The raw text to be escaped. The input typed by the user should have no
 	 *                     extra or deleted slashes.
-	 * @return string Text in the form of a LIKE phrase. The output is not SQL safe. Call $wpdb::prepare()
+	 * @return string Text in the form of a LIKE phrase. The output is not SQL safe. Call $WPDB::prepare()
 	 *                or real_escape next.
 	 */
 	public function esc_like( $text ) {
@@ -1486,12 +1486,12 @@ class wpdb {
 	 * Enables showing of database errors.
 	 *
 	 * This function should be used only to enable showing of errors.
-	 * wpdb::hide_errors() should be used instead for hiding of errors. However,
+	 * WPDB::hide_errors() should be used instead for hiding of errors. However,
 	 * this function can be used to enable and disable showing of database
 	 * errors.
 	 *
 	 * @since 0.71
-	 * @see wpdb::hide_errors()
+	 * @see WPDB::hide_errors()
 	 *
 	 * @param bool $show Whether to show or hide errors
 	 * @return bool Old value for showing errors.
@@ -1508,7 +1508,7 @@ class wpdb {
 	 * By default database errors are not shown.
 	 *
 	 * @since 0.71
-	 * @see wpdb::show_errors()
+	 * @see WPDB::show_errors()
 	 *
 	 * @return bool Whether showing of errors was active
 	 */
@@ -1525,7 +1525,7 @@ class wpdb {
 	 * call to this function they can be enabled.
 	 *
 	 * @since 2.5.0
-	 * @see wpdb::hide_errors()
+	 * @see WPDB::hide_errors()
 	 * @param bool $suppress Optional. New value. Defaults to true.
 	 * @return bool Old value
 	 */
@@ -1999,7 +1999,7 @@ class wpdb {
 	 *
 	 * @since 3.9.0
 	 *
-	 * @see wpdb::query()
+	 * @see WPDB::query()
 	 *
 	 * @param string $query The query to run.
 	 */
@@ -2086,12 +2086,12 @@ class wpdb {
 	/**
 	 * Insert a row into a table.
 	 *
-	 *     wpdb::insert( 'table', array( 'column' => 'foo', 'field' => 'bar' ) )
-	 *     wpdb::insert( 'table', array( 'column' => 'foo', 'field' => 1337 ), array( '%s', '%d' ) )
+	 *     WPDB::insert( 'table', array( 'column' => 'foo', 'field' => 'bar' ) )
+	 *     WPDB::insert( 'table', array( 'column' => 'foo', 'field' => 1337 ), array( '%s', '%d' ) )
 	 *
 	 * @since 2.5.0
-	 * @see wpdb::prepare()
-	 * @see wpdb::$field_types
+	 * @see WPDB::prepare()
+	 * @see WPDB::$field_types
 	 * @see wp_set_wpdb_vars()
 	 *
 	 * @param string       $table  Table name
@@ -2101,7 +2101,7 @@ class wpdb {
 	 * @param array|string $format Optional. An array of formats to be mapped to each of the value in $data.
 	 *                             If string, that format will be used for all of the values in $data.
 	 *                             A format is one of '%d', '%f', '%s' (integer, float, string).
-	 *                             If omitted, all values in $data will be treated as strings unless otherwise specified in wpdb::$field_types.
+	 *                             If omitted, all values in $data will be treated as strings unless otherwise specified in WPDB::$field_types.
 	 * @return int|false The number of rows inserted, or false on error.
 	 */
 	public function insert( $table, $data, $format = null ) {
@@ -2111,12 +2111,12 @@ class wpdb {
 	/**
 	 * Replace a row into a table.
 	 *
-	 *     wpdb::replace( 'table', array( 'column' => 'foo', 'field' => 'bar' ) )
-	 *     wpdb::replace( 'table', array( 'column' => 'foo', 'field' => 1337 ), array( '%s', '%d' ) )
+	 *     WPDB::replace( 'table', array( 'column' => 'foo', 'field' => 'bar' ) )
+	 *     WPDB::replace( 'table', array( 'column' => 'foo', 'field' => 1337 ), array( '%s', '%d' ) )
 	 *
 	 * @since 3.0.0
-	 * @see wpdb::prepare()
-	 * @see wpdb::$field_types
+	 * @see WPDB::prepare()
+	 * @see WPDB::$field_types
 	 * @see wp_set_wpdb_vars()
 	 *
 	 * @param string       $table  Table name
@@ -2126,7 +2126,7 @@ class wpdb {
 	 * @param array|string $format Optional. An array of formats to be mapped to each of the value in $data.
 	 *                             If string, that format will be used for all of the values in $data.
 	 *                             A format is one of '%d', '%f', '%s' (integer, float, string).
-	 *                             If omitted, all values in $data will be treated as strings unless otherwise specified in wpdb::$field_types.
+	 *                             If omitted, all values in $data will be treated as strings unless otherwise specified in WPDB::$field_types.
 	 * @return int|false The number of rows affected, or false on error.
 	 */
 	public function replace( $table, $data, $format = null ) {
@@ -2139,8 +2139,8 @@ class wpdb {
 	 * Runs an insert or replace query based on $type argument.
 	 *
 	 * @since 3.0.0
-	 * @see wpdb::prepare()
-	 * @see wpdb::$field_types
+	 * @see WPDB::prepare()
+	 * @see WPDB::$field_types
 	 * @see wp_set_wpdb_vars()
 	 *
 	 * @param string       $table  Table name
@@ -2150,7 +2150,7 @@ class wpdb {
 	 * @param array|string $format Optional. An array of formats to be mapped to each of the value in $data.
 	 *                             If string, that format will be used for all of the values in $data.
 	 *                             A format is one of '%d', '%f', '%s' (integer, float, string).
-	 *                             If omitted, all values in $data will be treated as strings unless otherwise specified in wpdb::$field_types.
+	 *                             If omitted, all values in $data will be treated as strings unless otherwise specified in WPDB::$field_types.
 	 * @param string $type         Optional. What type of operation is this? INSERT or REPLACE. Defaults to INSERT.
 	 * @return int|false The number of rows affected, or false on error.
 	 */
@@ -2190,12 +2190,12 @@ class wpdb {
 	/**
 	 * Update a row in the table
 	 *
-	 *     wpdb::update( 'table', array( 'column' => 'foo', 'field' => 'bar' ), array( 'ID' => 1 ) )
-	 *     wpdb::update( 'table', array( 'column' => 'foo', 'field' => 1337 ), array( 'ID' => 1 ), array( '%s', '%d' ), array( '%d' ) )
+	 *     WPDB::update( 'table', array( 'column' => 'foo', 'field' => 'bar' ), array( 'ID' => 1 ) )
+	 *     WPDB::update( 'table', array( 'column' => 'foo', 'field' => 1337 ), array( 'ID' => 1 ), array( '%s', '%d' ), array( '%d' ) )
 	 *
 	 * @since 2.5.0
-	 * @see wpdb::prepare()
-	 * @see wpdb::$field_types
+	 * @see WPDB::prepare()
+	 * @see WPDB::$field_types
 	 * @see wp_set_wpdb_vars()
 	 *
 	 * @param string       $table        Table name
@@ -2210,7 +2210,7 @@ class wpdb {
 	 * @param array|string $format       Optional. An array of formats to be mapped to each of the values in $data.
 	 *                                   If string, that format will be used for all of the values in $data.
 	 *                                   A format is one of '%d', '%f', '%s' (integer, float, string).
-	 *                                   If omitted, all values in $data will be treated as strings unless otherwise specified in wpdb::$field_types.
+	 *                                   If omitted, all values in $data will be treated as strings unless otherwise specified in WPDB::$field_types.
 	 * @param array|string $where_format Optional. An array of formats to be mapped to each of the values in $where.
 	 *                                   If string, that format will be used for all of the items in $where.
 	 *                                   A format is one of '%d', '%f', '%s' (integer, float, string).
@@ -2265,12 +2265,12 @@ class wpdb {
 	/**
 	 * Delete a row in the table
 	 *
-	 *     wpdb::delete( 'table', array( 'ID' => 1 ) )
-	 *     wpdb::delete( 'table', array( 'ID' => 1 ), array( '%d' ) )
+	 *     WPDB::delete( 'table', array( 'ID' => 1 ) )
+	 *     WPDB::delete( 'table', array( 'ID' => 1 ), array( '%d' ) )
 	 *
 	 * @since 3.4.0
-	 * @see wpdb::prepare()
-	 * @see wpdb::$field_types
+	 * @see WPDB::prepare()
+	 * @see WPDB::$field_types
 	 * @see wp_set_wpdb_vars()
 	 *
 	 * @param string       $table        Table name
@@ -2281,7 +2281,7 @@ class wpdb {
 	 * @param array|string $where_format Optional. An array of formats to be mapped to each of the values in $where.
 	 *                                   If string, that format will be used for all of the items in $where.
 	 *                                   A format is one of '%d', '%f', '%s' (integer, float, string).
-	 *                                   If omitted, all values in $where will be treated as strings unless otherwise specified in wpdb::$field_types.
+	 *                                   If omitted, all values in $where will be treated as strings unless otherwise specified in WPDB::$field_types.
 	 * @return int|false The number of rows updated, or false on error.
 	 */
 	public function delete( $table, $where, $where_format = null ) {
@@ -2393,11 +2393,11 @@ class wpdb {
 
 	/**
 	 * Adds field charsets to field/value/format arrays generated by
-	 * the wpdb::process_field_formats() method.
+	 * the WPDB::process_field_formats() method.
 	 *
 	 * @since 4.2.0
 	 *
-	 * @param array  $data  As it comes from the wpdb::process_field_formats() method.
+	 * @param array  $data  As it comes from the WPDB::process_field_formats() method.
 	 * @param string $table Table name.
 	 * @return array|false The same array as $data with additional 'charset' keys.
 	 */
@@ -2427,7 +2427,7 @@ class wpdb {
 	 *
 	 * @since 4.2.1
 	 *
-	 * @param array  $data  As it comes from the wpdb::process_field_charsets() method.
+	 * @param array  $data  As it comes from the WPDB::process_field_charsets() method.
 	 * @param string $table Table name.
 	 * @return array|false The same array as $data with additional 'length' keys, or false if
 	 *                     any of the values were too long for their corresponding field.
@@ -3357,7 +3357,7 @@ class wpdb {
 	/**
 	 * Wraps errors in a nice header and footer and dies.
 	 *
-	 * Will not die if wpdb::$show_errors is false.
+	 * Will not die if WPDB::$show_errors is false.
 	 *
 	 * @since 1.5.0
 	 *
@@ -3452,15 +3452,15 @@ class wpdb {
 	 *
 	 * Called when WordPress is generating the table scheme.
 	 *
-	 * Use `wpdb::has_cap( 'collation' )`.
+	 * Use `WPDB::has_cap( 'collation' )`.
 	 *
 	 * @since 2.5.0
-	 * @deprecated 3.5.0 Use wpdb::has_cap()
+	 * @deprecated 3.5.0 Use WPDB::has_cap()
 	 *
 	 * @return bool True if collation is supported, false if version does not
 	 */
 	public function supports_collation() {
-		_deprecated_function( __FUNCTION__, '3.5.0', 'wpdb::has_cap( \'collation\' )' );
+		_deprecated_function( __FUNCTION__, '3.5.0', 'WPDB::has_cap( \'collation\' )' );
 		return $this->has_cap( 'collation' );
 	}
 
@@ -3491,7 +3491,7 @@ class wpdb {
 	 * @since 4.1.0 Added support for the 'utf8mb4' feature.
 	 * @since 4.6.0 Added support for the 'utf8mb4_520' feature.
 	 *
-	 * @see wpdb::db_version()
+	 * @see WPDB::db_version()
 	 *
 	 * @param string $db_cap The feature to check for. Accepts 'collation',
 	 *                       'group_concat', 'subqueries', 'set_charset',
diff --git a/src/xmlrpc.php b/src/xmlrpc.php
index b36b21e951..d5940f2ec0 100644
--- a/src/xmlrpc.php
+++ b/src/xmlrpc.php
@@ -79,11 +79,11 @@ $post_default_title = '';
  *
  * @param string $class The name of the XML-RPC server class.
  */
-$wp_xmlrpc_server_class = apply_filters( 'wp_xmlrpc_server_class', 'wp_xmlrpc_server' );
-$wp_xmlrpc_server       = new $wp_xmlrpc_server_class;
+$WP_XMLRPC_Server_class = apply_filters( 'WP_XMLRPC_Server_class', 'WP_XMLRPC_Server' );
+$WP_XMLRPC_Server       = new $WP_XMLRPC_Server_class;
 
 // Fire off the request
-$wp_xmlrpc_server->serve_request();
+$WP_XMLRPC_Server->serve_request();
 
 exit;
 
diff --git a/tests/phpunit/includes/testcase-xmlrpc.php b/tests/phpunit/includes/testcase-xmlrpc.php
index 5fe312bc13..837a74a168 100644
--- a/tests/phpunit/includes/testcase-xmlrpc.php
+++ b/tests/phpunit/includes/testcase-xmlrpc.php
@@ -11,7 +11,7 @@ class WP_XMLRPC_UnitTestCase extends WP_UnitTestCase {
 
 		add_filter( 'pre_option_enable_xmlrpc', '__return_true' );
 
-		$this->myxmlrpcserver = new wp_xmlrpc_server();
+		$this->myxmlrpcserver = new WP_XMLRPC_Server();
 	}
 
 	function tearDown() {
diff --git a/tests/phpunit/tests/db.php b/tests/phpunit/tests/db.php
index 0583ae132a..46653378dd 100644
--- a/tests/phpunit/tests/db.php
+++ b/tests/phpunit/tests/db.php
@@ -359,7 +359,7 @@ class Tests_DB extends WP_UnitTestCase {
 
 	/**
 	 * @ticket 25604
-	 * @expectedIncorrectUsage wpdb::prepare
+	 * @expectedIncorrectUsage WPDB::prepare
 	 */
 	function test_prepare_without_arguments() {
 		global $wpdb;
@@ -378,7 +378,7 @@ class Tests_DB extends WP_UnitTestCase {
 	}
 
 	/**
-	 * @expectedIncorrectUsage wpdb::prepare
+	 * @expectedIncorrectUsage WPDB::prepare
 	 */
 	function test_prepare_sprintf_invalid_args() {
 		global $wpdb;
@@ -400,7 +400,7 @@ class Tests_DB extends WP_UnitTestCase {
 	}
 
 	/**
-	 * @expectedIncorrectUsage wpdb::prepare
+	 * @expectedIncorrectUsage WPDB::prepare
 	 */
 	function test_prepare_vsprintf_invalid_args() {
 		global $wpdb;
@@ -417,12 +417,12 @@ class Tests_DB extends WP_UnitTestCase {
 	/**
 	 * @ticket 42040
 	 * @dataProvider data_prepare_incorrect_arg_count
-	 * @expectedIncorrectUsage wpdb::prepare
+	 * @expectedIncorrectUsage WPDB::prepare
 	 */
 	public function test_prepare_incorrect_arg_count( $query, $args, $expected ) {
 		global $wpdb;
 
-		// $query is the first argument to be passed to wpdb::prepare()
+		// $query is the first argument to be passed to WPDB::prepare()
 		array_unshift( $args, $query );
 
 		// phpcs:ignore WordPress.PHP.NoSilencedErrors.Discouraged
@@ -691,7 +691,7 @@ class Tests_DB extends WP_UnitTestCase {
 	}
 
 	/**
-	 * wpdb::update() requires a WHERE condition.
+	 * WPDB::update() requires a WHERE condition.
 	 *
 	 * @ticket 26106
 	 */
@@ -1359,7 +1359,7 @@ class Tests_DB extends WP_UnitTestCase {
 		global $wpdb;
 
 		if ( $incorrect_usage ) {
-			$this->setExpectedIncorrectUsage( 'wpdb::prepare' );
+			$this->setExpectedIncorrectUsage( 'WPDB::prepare' );
 		}
 
 		if ( ! is_array( $values ) ) {
@@ -1379,7 +1379,7 @@ class Tests_DB extends WP_UnitTestCase {
 		global $wpdb;
 
 		if ( $incorrect_usage ) {
-			$this->setExpectedIncorrectUsage( 'wpdb::prepare' );
+			$this->setExpectedIncorrectUsage( 'WPDB::prepare' );
 		}
 
 		if ( ! is_array( $values ) ) {
@@ -1572,7 +1572,7 @@ class Tests_DB extends WP_UnitTestCase {
 		global $wpdb;
 
 		if ( $incorrect_usage ) {
-			$this->setExpectedIncorrectUsage( 'wpdb::prepare' );
+			$this->setExpectedIncorrectUsage( 'WPDB::prepare' );
 		}
 
 		$escape = esc_sql( $escape );
@@ -1613,7 +1613,7 @@ class Tests_DB extends WP_UnitTestCase {
 	}
 
 	/**
-	 * @expectedIncorrectUsage wpdb::prepare
+	 * @expectedIncorrectUsage WPDB::prepare
 	 */
 	function test_double_prepare() {
 		global $wpdb;
diff --git a/tests/phpunit/tests/db/charset.php b/tests/phpunit/tests/db/charset.php
index 3089ec9a74..81f9d76c66 100644
--- a/tests/phpunit/tests/db/charset.php
+++ b/tests/phpunit/tests/db/charset.php
@@ -659,7 +659,7 @@ class Tests_DB_Charset extends WP_UnitTestCase {
 	}
 
 	/**
-	 * Set of table definitions for testing wpdb::get_table_charset and wpdb::get_column_charset
+	 * Set of table definitions for testing WPDB::get_table_charset and WPDB::get_column_charset
 	 *
 	 * @var array
 	 */
diff --git a/tests/phpunit/tests/oembed/wpOembed.php b/tests/phpunit/tests/oembed/wpOembed.php
index c148dd555c..9df3d44da2 100644
--- a/tests/phpunit/tests/oembed/wpOembed.php
+++ b/tests/phpunit/tests/oembed/wpOembed.php
@@ -3,9 +3,9 @@
 /**
  * @group oembed
  */
-class Tests_WP_oEmbed extends WP_UnitTestCase {
+class Tests_WP_OEmbed extends WP_UnitTestCase {
 	/**
-	 * @var WP_oEmbed
+	 * @var WP_OEmbed
 	 */
 	protected $oembed;
 

diff --git a/src/wp-includes/class-oembed.php b/src/wp-includes/class-oembed.php
index dd3e5687f0..3a8cb230dc 100644
--- a/src/wp-includes/class-oembed.php
+++ b/src/wp-includes/class-oembed.php
@@ -16,7 +16,7 @@
  *
  * @since 2.9.0
  */
-class WP_oEmbed {
+class WP_OEmbed {
 
 	/**
 	 * A list of oEmbed providers.
@@ -245,7 +245,7 @@ class WP_oEmbed {
 	 *
 	 * @since 4.0.0
 	 *
-	 * @see WP_oEmbed::discover()
+	 * @see WP_OEmbed::discover()
 	 *
 	 * @param string        $url  The URL to the content.
 	 * @param string|array  $args Optional provider arguments.
@@ -334,7 +334,7 @@ class WP_oEmbed {
 	/**
 	 * Takes a URL and attempts to return the oEmbed data.
 	 *
-	 * @see WP_oEmbed::fetch()
+	 * @see WP_OEmbed::fetch()
 	 *
 	 * @since 4.8.0
 	 *
@@ -363,8 +363,8 @@ class WP_oEmbed {
 	/**
 	 * The do-it-all function that takes a URL and attempts to return the HTML.
 	 *
-	 * @see WP_oEmbed::fetch()
-	 * @see WP_oEmbed::data2html()
+	 * @see WP_OEmbed::fetch()
+	 * @see WP_OEmbed::data2html()
 	 *
 	 * @since 2.9.0
 	 *
@@ -649,7 +649,7 @@ class WP_oEmbed {
 	}
 
 	/**
 	 * Converts a data object from WP_oEmbed::fetch() and returns the HTML.
 	 *
 	 * @since 2.9.0
 	 *
@@ -715,7 +715,7 @@ class WP_oEmbed {
 	 * @since 3.0.0
 	 *
 	 * @param string $html Existing HTML.
 	 * @param object $data Data object from WP_oEmbed::data2html()
 	 * @param string $url The original URL passed to oEmbed.
 	 * @return string Possibly modified $html
 	 */
@@ -649,7 +649,7 @@ class WP_oEmbed {
 
 	/**
-	 * Converts a data object from WP_oEmbed::fetch() and returns the HTML.
+	 * Converts a data object from WP_OEmbed::fetch() and returns the HTML.
 	 *
 	 * @since 2.9.0
@@ -715,7 +715,7 @@ class WP_oEmbed {
 	 *
 	 * @param string $html Existing HTML.
-	 * @param object $data Data object from WP_oEmbed::data2html()
+	 * @param object $data Data object from WP_OEmbed::data2html()
 	 * @param string $url The original URL passed to oEmbed.
 	 * @return string Possibly modified $html
diff --git a/src/wp-includes/class-wp-oembed-controller.php b/src/wp-includes/class-wp-oembed-controller.php
index 2b08516894..7a6a32d27c 100644
--- a/src/wp-includes/class-wp-oembed-controller.php
+++ b/src/wp-includes/class-wp-oembed-controller.php
@@ -1,6 +1,6 @@
 <?php
 /**
- * WP_oEmbed_Controller class, used to provide an oEmbed endpoint.
+ * WP_OEmbed_Controller class, used to provide an oEmbed endpoint.
  *
  * @package WordPress
  * @subpackage Embeds
@@ -15,7 +15,7 @@
  *
  * @since 4.4.0
  */
-final class WP_oEmbed_Controller {
+final class WP_OEmbed_Controller {
 	/**
 	 * Register the oEmbed REST API route.
 	 *
@@ -155,7 +155,7 @@ final class WP_oEmbed_Controller {
 	 *
 	 * @since 4.8.0
 	 *
-	 * @see WP_oEmbed::get_html()
+	 * @see WP_OEmbed::get_html()
 	 * @param WP_REST_Request $request Full data about the request.
 	 * @return object|WP_Error oEmbed response data or WP_Error on failure.
 	 */
@@ -173,7 +173,7 @@ final class WP_oEmbed_Controller {
 		$url = $request['url'];
 		unset( $args['url'] );
 
 		// Copy maxwidth/maxheight to width/height since WP_oEmbed::fetch() uses these arg names.
 		if ( isset( $args['maxwidth'] ) ) {
 			$args['width'] = $args['maxwidth'];
 		}
@@ -173,7 +173,7 @@ final class WP_oEmbed_Controller {
 		unset( $args['url'] );
 
-		// Copy maxwidth/maxheight to width/height since WP_oEmbed::fetch() uses these arg names.
+		// Copy maxwidth/maxheight to width/height since WP_OEmbed::fetch() uses these arg names.
 		if ( isset( $args['maxwidth'] ) ) {
 			$args['width'] = $args['maxwidth'];